<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="ja">
<context>
    <name>AnglesOptionWidget</name>
    <message>
        <location filename="gui/opt/AnglesOptionWidget.cpp" line="28"/>
        <source>Angles</source>
        <translation>角度</translation>
    </message>
    <message>
        <location filename="gui/opt/AnglesOptionWidget.cpp" line="40"/>
        <source>D&amp;egrees</source>
        <translation>度(&amp;E)</translation>
    </message>
    <message>
        <location filename="gui/opt/AnglesOptionWidget.cpp" line="45"/>
        <source>&amp;Radians</source>
        <translation>ラジアン(&amp;R)</translation>
    </message>
</context>
<context>
    <name>AxisDataOptionWidget</name>
    <message>
        <location filename="gui/opt/AxisDataOptionWidget.cpp" line="54"/>
        <source> Axis</source>
        <translation> 軸</translation>
    </message>
    <message>
        <location filename="gui/opt/AxisDataOptionWidget.cpp" line="45"/>
        <source>Time/Date</source>
        <translation>時間/日付</translation>
    </message>
    <message>
        <location filename="gui/opt/AxisDataOptionWidget.cpp" line="29"/>
        <source>Data</source>
        <translation>データ</translation>
    </message>
    <message>
        <location filename="gui/opt/AxisDataOptionWidget.cpp" line="30"/>
        <source>set &lt;i&gt;axis&lt;/i&gt;data</source>
        <translation>set &lt;i&gt;軸&lt;/i&gt; data</translation>
    </message>
</context>
<context>
    <name>AxisLabelOptionWidget</name>
    <message>
        <location filename="gui/opt/AxisLabelOptionWidget.cpp" line="31"/>
        <source>Label</source>
        <translation>ラベル</translation>
    </message>
    <message>
        <location filename="gui/opt/AxisLabelOptionWidget.cpp" line="68"/>
        <source>T&amp;ext:</source>
        <translation>テキスト(&amp;E):</translation>
    </message>
    <message>
        <location filename="gui/opt/AxisLabelOptionWidget.cpp" line="77"/>
        <source>X O&amp;ffset:</source>
        <translation>X オフセット(&amp;F):</translation>
    </message>
    <message>
        <location filename="gui/opt/AxisLabelOptionWidget.cpp" line="86"/>
        <source>&amp;Y Offset:</source>
        <translation>&amp;Y オフセット:</translation>
    </message>
    <message>
        <location filename="gui/opt/AxisLabelOptionWidget.cpp" line="94"/>
        <source>Fo&amp;nt Name:</source>
        <translation>フォントの名前(&amp;N):</translation>
    </message>
    <message>
        <location filename="gui/opt/AxisLabelOptionWidget.cpp" line="32"/>
        <source>set &lt;i&gt;axis&lt;/i&gt;label</source>
        <translation>set &lt;i&gt;軸&lt;/i&gt; label</translation>
    </message>
</context>
<context>
    <name>AxisOptionWidget</name>
    <message>
        <location filename="gui/opt/AxisOptionWidget.cpp" line="42"/>
        <source>A&amp;xis:</source>
        <translation>軸(&amp;X):</translation>
    </message>
</context>
<context>
    <name>AxisRangeOptionWidget</name>
    <message>
        <location filename="gui/opt/AxisRangeOptionWidget.cpp" line="30"/>
        <source>Range</source>
        <translation>範囲</translation>
    </message>
    <message>
        <location filename="gui/opt/AxisRangeOptionWidget.cpp" line="31"/>
        <source>set &lt;i&gt;axis&lt;/i&gt;range</source>
        <translation>set &lt;i&gt;軸&lt;/i&gt; range</translation>
    </message>
    <message>
        <location filename="gui/opt/AxisRangeOptionWidget.cpp" line="67"/>
        <source>&amp;Minimum:</source>
        <translation>最小値(&amp;M):</translation>
    </message>
    <message>
        <location filename="gui/opt/AxisRangeOptionWidget.cpp" line="75"/>
        <source>Max&amp;imum:</source>
        <translation>最大値(&amp;I):</translation>
    </message>
</context>
<context>
    <name>AxisTics</name>
    <message>
        <location filename="opt/AxisTics.cpp" line="30"/>
        <source>border</source>
        <translation>縁</translation>
    </message>
    <message>
        <location filename="opt/AxisTics.cpp" line="31"/>
        <source>axis</source>
        <translation>軸</translation>
    </message>
</context>
<context>
    <name>AxisTicsOptionWidget</name>
    <message>
        <location filename="gui/opt/AxisTicsOptionWidget.cpp" line="33"/>
        <source>Tics</source>
        <translation>目盛り</translation>
    </message>
    <message>
        <location filename="gui/opt/AxisTicsOptionWidget.cpp" line="66"/>
        <source>Ac&amp;tivation</source>
        <translation>有効化(&amp;T)</translation>
    </message>
    <message>
        <location filename="gui/opt/AxisTicsOptionWidget.cpp" line="79"/>
        <source>&amp;Mirroring</source>
        <translation>ミラー(&amp;M)</translation>
    </message>
    <message>
        <location filename="gui/opt/AxisTicsOptionWidget.cpp" line="84"/>
        <source>&amp;Rotation</source>
        <translation>回転(&amp;R)</translation>
    </message>
    <message>
        <location filename="gui/opt/AxisTicsOptionWidget.cpp" line="93"/>
        <source>&amp;Start:</source>
        <translation>開始(&amp;S):</translation>
    </message>
    <message>
        <location filename="gui/opt/AxisTicsOptionWidget.cpp" line="101"/>
        <source>&amp;Increment:</source>
        <translation>増分(&amp;I):</translation>
    </message>
    <message>
        <location filename="gui/opt/AxisTicsOptionWidget.cpp" line="109"/>
        <source>&amp;End:</source>
        <translation>終了(&amp;E):</translation>
    </message>
    <message>
        <location filename="gui/opt/AxisTicsOptionWidget.cpp" line="172"/>
        <source>&amp;Position</source>
        <translation>位置(&amp;P)</translation>
    </message>
    <message>
        <location filename="gui/opt/AxisTicsOptionWidget.cpp" line="173"/>
        <source>O&amp;thers</source>
        <translation>その他(&amp;T)</translation>
    </message>
    <message>
        <location filename="gui/opt/AxisTicsOptionWidget.cpp" line="34"/>
        <source>set &lt;i&gt;axis&lt;/i&gt;tics</source>
        <translation>set &lt;i&gt;軸&lt;/i&gt; tics</translation>
    </message>
    <message>
        <location filename="gui/opt/AxisTicsOptionWidget.cpp" line="142"/>
        <source>Auto</source>
        <translation>自動</translation>
    </message>
    <message>
        <location filename="gui/opt/AxisTicsOptionWidget.cpp" line="143"/>
        <source>Start/Increment/End</source>
        <translation>開始/増分/終了</translation>
    </message>
    <message>
        <location filename="gui/opt/AxisTicsOptionWidget.cpp" line="144"/>
        <source>Labels/Positions</source>
        <translation>ラベル/位置</translation>
    </message>
</context>
<context>
    <name>BarOptionWidget</name>
    <message>
        <location filename="gui/opt/BarOptionWidget.cpp" line="42"/>
        <source>Quantitative</source>
        <translation>定量的</translation>
    </message>
    <message>
        <location filename="gui/opt/BarOptionWidget.cpp" line="53"/>
        <source>Qualitative</source>
        <translation>定性的</translation>
    </message>
    <message>
        <location filename="gui/opt/BarOptionWidget.cpp" line="56"/>
        <source>small</source>
        <translation>小</translation>
    </message>
    <message>
        <location filename="gui/opt/BarOptionWidget.cpp" line="57"/>
        <source>large</source>
        <translation>大</translation>
    </message>
    <message>
        <location filename="gui/opt/BarOptionWidget.cpp" line="30"/>
        <source>Bar Size</source>
        <translation>棒のサイズ</translation>
    </message>
</context>
<context>
    <name>BoxWidthOptionWidget</name>
    <message>
        <location filename="gui/opt/BoxWidthOptionWidget.cpp" line="47"/>
        <source>&quot;A&amp;bsolute&quot; Value</source>
        <translation>絶対的な値(&amp;B)</translation>
    </message>
    <message>
        <location filename="gui/opt/BoxWidthOptionWidget.cpp" line="30"/>
        <source>Box Width</source>
        <translation>棒の幅</translation>
    </message>
    <message>
        <location filename="gui/opt/BoxWidthOptionWidget.cpp" line="42"/>
        <source>&amp;Specify</source>
        <translation>指定する(&amp;S)</translation>
    </message>
</context>
<context>
    <name>ConsoleDialog</name>
    <message>
        <location filename="gui/ConsoleDialog.cpp" line="29"/>
        <source>Console</source>
        <translation>コンソール</translation>
    </message>
</context>
<context>
    <name>DummyOptionWidget</name>
    <message>
        <location filename="gui/opt/DummyOptionWidget.cpp" line="53"/>
        <source>Variable</source>
        <translation>変数</translation>
    </message>
    <message>
        <location filename="gui/opt/DummyOptionWidget.cpp" line="29"/>
        <source>Dummy Variable</source>
        <translation>ダミー変数</translation>
    </message>
</context>
<context>
    <name>Encoding</name>
    <message>
        <location filename="opt/Encoding.cpp" line="22"/>
        <source>default</source>
        <translation>標準設定</translation>
    </message>
</context>
<context>
    <name>EncodingOptionWidget</name>
    <message>
        <location filename="gui/opt/EncodingOptionWidget.cpp" line="29"/>
        <source>Encoding</source>
        <translation>エンコーディング</translation>
    </message>
</context>
<context>
    <name>FitBasicWidget</name>
    <message>
        <location filename="gui/fit/FitBasicWidget.cpp" line="69"/>
        <source>&amp;Open...</source>
        <translation>開く(&amp;O)...</translation>
    </message>
    <message>
        <location filename="gui/fit/FitBasicWidget.cpp" line="72"/>
        <source>&amp;Parameter File:</source>
        <translation>パラメータファイル(&amp;P):</translation>
    </message>
    <message>
        <location filename="gui/fit/FitBasicWidget.cpp" line="85"/>
        <source>Op&amp;en...</source>
        <translation>開く(&amp;E)...</translation>
    </message>
    <message>
        <location filename="gui/fit/FitBasicWidget.cpp" line="92"/>
        <source>Co&amp;mma Seperated List:</source>
        <translation>カンマ区切りリスト(&amp;M):</translation>
    </message>
    <message>
        <location filename="gui/fit/FitBasicWidget.cpp" line="120"/>
        <source>Parameters</source>
        <translation>パラメータ</translation>
    </message>
    <message>
        <location filename="gui/fit/FitBasicWidget.cpp" line="189"/>
        <source>Open a data file</source>
        <translation>データファイルを開く</translation>
    </message>
    <message>
        <location filename="gui/fit/FitBasicWidget.cpp" line="201"/>
        <source>Open a parameter file</source>
        <translation>パラメータファイルを開く</translation>
    </message>
    <message>
        <location filename="gui/fit/FitBasicWidget.cpp" line="34"/>
        <source>Basic</source>
        <translation>基本</translation>
    </message>
    <message>
        <location filename="gui/fit/FitBasicWidget.cpp" line="46"/>
        <source>F&amp;unction:</source>
        <translation>関数(&amp;U):</translation>
    </message>
    <message>
        <location filename="gui/fit/FitBasicWidget.cpp" line="61"/>
        <source>&amp;Data File:</source>
        <translation>データファイル(&amp;D):</translation>
    </message>
    <message>
        <location filename="gui/fit/FitBasicWidget.cpp" line="37"/>
        <source>fit &amp;lt;function&amp;gt; &apos;&amp;lt;datafile&amp;gt;&apos;&lt;br&gt;via &apos;&amp;lt;parameter file&amp;gt;&apos;&lt;br&gt;| &amp;lt;var1&amp;gt;{,&amp;lt;var2&amp;gt;,...}</source>
        <translation>fit &amp;lt;関数&amp;gt; &apos;&amp;lt;データファイル&amp;gt;&apos;&lt;br&gt;via &apos;&amp;lt;パラメータファイル&amp;gt;&apos;&lt;br&gt;| &amp;lt;変数1&amp;gt;{,&amp;lt;変数2&amp;gt;,...}</translation>
    </message>
</context>
<context>
    <name>FitDialog</name>
    <message>
        <location filename="gui/FitDialog.cpp" line="87"/>
        <source>&amp;Fit</source>
        <translation>フィット(&amp;F)</translation>
    </message>
    <message>
        <location filename="gui/FitDialog.cpp" line="90"/>
        <source>&amp;Close</source>
        <translation>閉じる(&amp;C)</translation>
    </message>
    <message>
        <location filename="gui/FitDialog.cpp" line="54"/>
        <source>Fittings</source>
        <translation>フィッティング</translation>
    </message>
</context>
<context>
    <name>FitModifierWidget</name>
    <message>
        <location filename="gui/fit/FitModifierWidget.cpp" line="44"/>
        <source> Column:</source>
        <translation> 列:</translation>
    </message>
    <message>
        <location filename="gui/fit/FitModifierWidget.cpp" line="55"/>
        <source>Specify a S&amp;tarting Index</source>
        <translation>開始インデックスを指定する(&amp;T)</translation>
    </message>
    <message>
        <location filename="gui/fit/FitModifierWidget.cpp" line="64"/>
        <source>Specify a &amp;Ending Index</source>
        <translation>終了インデックスを指定する(&amp;E)</translation>
    </message>
    <message>
        <location filename="gui/fit/FitModifierWidget.cpp" line="73"/>
        <source>Specify I&amp;ncrement of Index</source>
        <translation>インデックスの増分を指定する(&amp;N)</translation>
    </message>
    <message>
        <location filename="gui/fit/FitModifierWidget.cpp" line="82"/>
        <source>Specify Point Increment</source>
        <translation>点の増分を指定する</translation>
    </message>
    <message>
        <location filename="gui/fit/FitModifierWidget.cpp" line="89"/>
        <source>Specify Line Increment</source>
        <translation>線の増分を指定する</translation>
    </message>
    <message>
        <location filename="gui/fit/FitModifierWidget.cpp" line="96"/>
        <source>Specify a Start Point</source>
        <translation>開始点を指定する</translation>
    </message>
    <message>
        <location filename="gui/fit/FitModifierWidget.cpp" line="103"/>
        <source>Specify a Start Line</source>
        <translation>開始線を指定する</translation>
    </message>
    <message>
        <location filename="gui/fit/FitModifierWidget.cpp" line="110"/>
        <source>Specify a End Point</source>
        <translation>終了点を指定する</translation>
    </message>
    <message>
        <location filename="gui/fit/FitModifierWidget.cpp" line="117"/>
        <source>Specify a End Line</source>
        <translation>終了線を指定する</translation>
    </message>
    <message>
        <location filename="gui/fit/FitModifierWidget.cpp" line="181"/>
        <source>&amp;Sampling</source>
        <translation>サンプリング(&amp;S)</translation>
    </message>
    <message>
        <location filename="gui/fit/FitModifierWidget.cpp" line="182"/>
        <source>C&amp;olumns</source>
        <translation>列(&amp;O)</translation>
    </message>
    <message>
        <location filename="gui/fit/FitModifierWidget.cpp" line="33"/>
        <source>Data File</source>
        <translation>データファイル</translation>
    </message>
    <message>
        <location filename="gui/fit/FitModifierWidget.cpp" line="180"/>
        <source>&amp;Indexes</source>
        <translation>インデックス(&amp;I)</translation>
    </message>
    <message>
        <location filename="gui/fit/FitModifierWidget.cpp" line="51"/>
        <source>Fo&amp;rmat:</source>
        <translation>フォーマット(&amp;R):</translation>
    </message>
    <message>
        <location filename="gui/fit/FitModifierWidget.cpp" line="36"/>
        <source>fit {index &amp;lt;index list&amp;gt;}&lt;br&gt;{every &amp;lt;every list&amp;gt;}&lt;br&gt;{using &amp;lt;using list&amp;gt;}</source>
        <translation>fit {index &amp;lt;index リスト&amp;gt;}&lt;br&gt;{every &amp;lt;every リスト&amp;gt;}&lt;br&gt;{using &amp;lt;using リスト&amp;gt;}</translation>
    </message>
    <message>
        <location filename="gui/fit/FitModifierWidget.cpp" line="138"/>
        <source>fit {index &amp;lt;index list&amp;gt;}</source>
        <translation>fit {index &amp;lt;index リスト&amp;gt;}</translation>
    </message>
    <message>
        <location filename="gui/fit/FitModifierWidget.cpp" line="160"/>
        <source>fit {every &amp;lt;every list&amp;gt;}</source>
        <translation>fit {every &amp;lt;every リスト&amp;gt;}</translation>
    </message>
    <message>
        <location filename="gui/fit/FitModifierWidget.cpp" line="176"/>
        <source>fit {using &amp;lt;using list&amp;gt;}</source>
        <translation>fit {using &amp;lt;using リスト&amp;gt;}</translation>
    </message>
</context>
<context>
    <name>FitOthersWidget</name>
    <message>
        <location filename="gui/fit/FitOthersWidget.cpp" line="35"/>
        <source>Fit Limit:</source>
        <translation>フィット限界:</translation>
    </message>
    <message>
        <location filename="gui/fit/FitOthersWidget.cpp" line="47"/>
        <source>Fit Max Iterations:</source>
        <translation>フィット最大繰り返し:</translation>
    </message>
    <message>
        <location filename="gui/fit/FitOthersWidget.cpp" line="61"/>
        <source>Special Variables</source>
        <translation>特別変数</translation>
    </message>
    <message>
        <location filename="gui/fit/FitOthersWidget.cpp" line="32"/>
        <source>Others</source>
        <translation>その他</translation>
    </message>
</context>
<context>
    <name>FitRangeWidget</name>
    <message>
        <location filename="gui/fit/FitRangeWidget.cpp" line="43"/>
        <source>Variable Name:</source>
        <translation>変数名:</translation>
    </message>
    <message>
        <location filename="gui/fit/FitRangeWidget.cpp" line="48"/>
        <source>Min:</source>
        <translation>最小:</translation>
    </message>
    <message>
        <location filename="gui/fit/FitRangeWidget.cpp" line="53"/>
        <source>Max:</source>
        <translation>最大:</translation>
    </message>
    <message>
        <location filename="gui/fit/FitRangeWidget.cpp" line="67"/>
        <source> Range</source>
        <translation> の範囲</translation>
    </message>
    <message>
        <location filename="gui/fit/FitRangeWidget.cpp" line="30"/>
        <source>Range</source>
        <translation>範囲</translation>
    </message>
    <message>
        <location filename="gui/fit/FitRangeWidget.cpp" line="31"/>
        <source>fit {[xrange] {[yrange]}}</source>
        <translation>fit {[x の範囲] {[y の範囲]}}</translation>
    </message>
</context>
<context>
    <name>FormatOptionWidget</name>
    <message>
        <location filename="gui/opt/FormatOptionWidget.cpp" line="29"/>
        <source>Format</source>
        <translation>フォーマット</translation>
    </message>
    <message>
        <location filename="gui/opt/FormatOptionWidget.cpp" line="53"/>
        <source> Axis</source>
        <translation> 軸</translation>
    </message>
</context>
<context>
    <name>GridOptionWidget</name>
    <message>
        <location filename="gui/opt/GridOptionWidget.cpp" line="28"/>
        <source>Grid</source>
        <translation>格子</translation>
    </message>
    <message>
        <location filename="gui/opt/GridOptionWidget.cpp" line="44"/>
        <source> Axis</source>
        <translation> 軸</translation>
    </message>
</context>
<context>
    <name>Key</name>
    <message>
        <location filename="opt/Key.cpp" line="30"/>
        <source>left</source>
        <translation>左</translation>
    </message>
    <message>
        <location filename="opt/Key.cpp" line="31"/>
        <source>right</source>
        <translation>右</translation>
    </message>
    <message>
        <location filename="opt/Key.cpp" line="32"/>
        <source>top</source>
        <translation>上</translation>
    </message>
    <message>
        <location filename="opt/Key.cpp" line="33"/>
        <source>bottom</source>
        <translation>中の下</translation>
    </message>
    <message>
        <location filename="opt/Key.cpp" line="34"/>
        <source>outside</source>
        <translation>外側</translation>
    </message>
    <message>
        <location filename="opt/Key.cpp" line="35"/>
        <source>below</source>
        <translation>外の下</translation>
    </message>
</context>
<context>
    <name>KeyOptionWidget</name>
    <message>
        <location filename="gui/opt/KeyOptionWidget.cpp" line="120"/>
        <source>Left Justify</source>
        <translation>左寄せ</translation>
    </message>
    <message>
        <location filename="gui/opt/KeyOptionWidget.cpp" line="125"/>
        <source>Reverse</source>
        <translation>逆</translation>
    </message>
    <message>
        <location filename="gui/opt/KeyOptionWidget.cpp" line="130"/>
        <source>Auto Titles</source>
        <translation>自動タイトル</translation>
    </message>
    <message>
        <location filename="gui/opt/KeyOptionWidget.cpp" line="135"/>
        <source>Enhanced</source>
        <translation>強化</translation>
    </message>
    <message>
        <location filename="gui/opt/KeyOptionWidget.cpp" line="140"/>
        <source>Sample Length:</source>
        <translation>サンプルの長さ:</translation>
    </message>
    <message>
        <location filename="gui/opt/KeyOptionWidget.cpp" line="147"/>
        <source>Spacing:</source>
        <translation>スペース:</translation>
    </message>
    <message>
        <location filename="gui/opt/KeyOptionWidget.cpp" line="154"/>
        <source>Width Increment:</source>
        <translation>幅の増分:</translation>
    </message>
    <message>
        <location filename="gui/opt/KeyOptionWidget.cpp" line="162"/>
        <source>Height Increment:</source>
        <translation>高さの増分:</translation>
    </message>
    <message>
        <location filename="gui/opt/KeyOptionWidget.cpp" line="170"/>
        <source>Legend Title:</source>
        <translation>凡例のタイトル:</translation>
    </message>
    <message>
        <location filename="gui/opt/KeyOptionWidget.cpp" line="41"/>
        <source>Legend</source>
        <translation>凡例</translation>
    </message>
    <message>
        <location filename="gui/opt/KeyOptionWidget.cpp" line="59"/>
        <source>Ac&amp;tivation</source>
        <translation>有効化(&amp;T)</translation>
    </message>
    <message>
        <location filename="gui/opt/KeyOptionWidget.cpp" line="256"/>
        <source>&amp;Position</source>
        <translation>位置(&amp;P)</translation>
    </message>
    <message>
        <location filename="gui/opt/KeyOptionWidget.cpp" line="181"/>
        <source>&amp;Line Type:</source>
        <translation>線の種類(&amp;L):</translation>
    </message>
    <message>
        <location filename="gui/opt/KeyOptionWidget.cpp" line="189"/>
        <source>L&amp;ine Width:</source>
        <translation>線の幅(&amp;I):</translation>
    </message>
    <message>
        <location filename="gui/opt/KeyOptionWidget.cpp" line="208"/>
        <source>Bo&amp;x</source>
        <translation>ボックス(&amp;X)</translation>
    </message>
    <message>
        <location filename="gui/opt/KeyOptionWidget.cpp" line="258"/>
        <source>Ot&amp;hers</source>
        <translation>その他(&amp;H)</translation>
    </message>
    <message>
        <location filename="gui/opt/KeyOptionWidget.cpp" line="112"/>
        <source>Corner</source>
        <translation>角</translation>
    </message>
    <message>
        <location filename="gui/opt/KeyOptionWidget.cpp" line="113"/>
        <source>Coordinate</source>
        <translation>座標</translation>
    </message>
    <message>
        <location filename="gui/opt/KeyOptionWidget.cpp" line="257"/>
        <source>&amp;Box and Title</source>
        <translation>ボックスとタイトル(&amp;B)</translation>
    </message>
</context>
<context>
    <name>LogScaleOptionWidget</name>
    <message>
        <location filename="gui/opt/LogScaleOptionWidget.cpp" line="29"/>
        <source>Log Scale</source>
        <translation>対数スケール</translation>
    </message>
    <message>
        <location filename="gui/opt/LogScaleOptionWidget.cpp" line="46"/>
        <source> Axis</source>
        <translation> 軸</translation>
    </message>
</context>
<context>
    <name>MAxisTicsOptionWidget</name>
    <message>
        <location filename="gui/opt/MAxisTicsOptionWidget.cpp" line="30"/>
        <source>Mini Tics</source>
        <translation>小目盛り</translation>
    </message>
    <message>
        <location filename="gui/opt/MAxisTicsOptionWidget.cpp" line="63"/>
        <source>D&amp;efault</source>
        <translation>標準設定(&amp;E)</translation>
    </message>
    <message>
        <location filename="gui/opt/MAxisTicsOptionWidget.cpp" line="68"/>
        <source>&amp;Interval</source>
        <translation>間隔(&amp;I)</translation>
    </message>
    <message>
        <location filename="gui/opt/MAxisTicsOptionWidget.cpp" line="31"/>
        <source>set m&lt;i&gt;axis&lt;/i&gt;tics</source>
        <translation>set m&lt;i&gt;軸&lt;/i&gt; tics</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="gui/MainWindow.cpp" line="59"/>
        <source>File Name</source>
        <translation>ファイル名</translation>
    </message>
    <message>
        <location filename="gui/MainWindow.cpp" line="48"/>
        <source>Function</source>
        <translation>関数</translation>
    </message>
    <message>
        <location filename="gui/MainWindow.cpp" line="77"/>
        <source>&amp;Add</source>
        <translation>追加(&amp;A)</translation>
    </message>
    <message>
        <location filename="gui/MainWindow.cpp" line="87"/>
        <source>O&amp;ption...</source>
        <translation>オプション(&amp;P)...</translation>
    </message>
    <message>
        <location filename="gui/MainWindow.cpp" line="95"/>
        <source>&amp;Up</source>
        <translation>上(&amp;U)</translation>
    </message>
    <message>
        <location filename="gui/MainWindow.cpp" line="101"/>
        <source>&amp;Down</source>
        <translation>下(&amp;D)</translation>
    </message>
    <message>
        <location filename="gui/MainWindow.cpp" line="107"/>
        <source>D&amp;elete</source>
        <translation>削除(&amp;E)</translation>
    </message>
    <message>
        <location filename="gui/MainWindow.cpp" line="553"/>
        <source>&amp;Quit</source>
        <translation>終了(&amp;Q)</translation>
    </message>
    <message>
        <location filename="gui/MainWindow.cpp" line="185"/>
        <source>&amp;2D Plot</source>
        <translation>&amp;2D プロット</translation>
    </message>
    <message>
        <location filename="gui/MainWindow.cpp" line="192"/>
        <source>&amp;3D Plot</source>
        <translation>&amp;3D プロット</translation>
    </message>
    <message>
        <location filename="gui/MainWindow.cpp" line="233"/>
        <source>&amp;About</source>
        <translation>Cueplot について(&amp;A)</translation>
    </message>
    <message>
        <location filename="gui/MainWindow.cpp" line="247"/>
        <source>&amp;File</source>
        <translation>ファイル(&amp;F)</translation>
    </message>
    <message>
        <location filename="gui/MainWindow.cpp" line="254"/>
        <source>&amp;Command</source>
        <translation>コマンド(&amp;C)</translation>
    </message>
    <message>
        <location filename="gui/MainWindow.cpp" line="267"/>
        <source>&amp;Help</source>
        <translation>ヘルプ(&amp;H)</translation>
    </message>
    <message>
        <location filename="gui/MainWindow.cpp" line="240"/>
        <source>About &amp;Qt</source>
        <translation>&amp;Qt について</translation>
    </message>
    <message>
        <location filename="gui/MainWindow.cpp" line="151"/>
        <source>&amp;Open...</source>
        <translation>開く(&amp;O)...</translation>
    </message>
    <message>
        <location filename="gui/MainWindow.cpp" line="165"/>
        <source>Save &amp;As...</source>
        <translation>名前を付けて保存(&amp;A)...</translation>
    </message>
    <message>
        <location filename="gui/MainWindow.cpp" line="199"/>
        <source>&amp;Raw Commands...</source>
        <translation>生のコマンド(&amp;R)...</translation>
    </message>
    <message>
        <location filename="gui/MainWindow.cpp" line="204"/>
        <source>&amp;Fittings...</source>
        <translation>フィッティング(&amp;F)...</translation>
    </message>
    <message>
        <location filename="gui/MainWindow.cpp" line="209"/>
        <source>&amp;Settings...</source>
        <translation>設定(&amp;S)...</translation>
    </message>
    <message>
        <location filename="gui/MainWindow.cpp" line="158"/>
        <source>&amp;Save</source>
        <translation>保存(&amp;S)</translation>
    </message>
    <message>
        <location filename="gui/MainWindow.cpp" line="408"/>
        <source>Save under a file name</source>
        <translation>名前を付けて保存する</translation>
    </message>
    <message>
        <location filename="gui/MainWindow.cpp" line="420"/>
        <source>Open a file</source>
        <translation>ファイルを開く</translation>
    </message>
    <message>
        <location filename="gui/MainWindow.cpp" line="387"/>
        <source>Open a data file</source>
        <translation>データファイルを開く</translation>
    </message>
    <message>
        <location filename="gui/MainWindow.cpp" line="514"/>
        <source>About %1</source>
        <translation>%1 について</translation>
    </message>
    <message>
        <location filename="gui/MainWindow.cpp" line="186"/>
        <source>F2</source>
        <translation>F2</translation>
    </message>
    <message>
        <location filename="gui/MainWindow.cpp" line="193"/>
        <source>F3</source>
        <translation>F3</translation>
    </message>
    <message>
        <location filename="gui/MainWindow.cpp" line="152"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="gui/MainWindow.cpp" line="273"/>
        <source>Tool Bar</source>
        <translation>ツールバー</translation>
    </message>
    <message>
        <location filename="gui/MainWindow.cpp" line="221"/>
        <source>&amp;Console...</source>
        <translation>コンソール(&amp;C)...</translation>
    </message>
    <message>
        <location filename="gui/MainWindow.cpp" line="261"/>
        <source>&amp;Settings</source>
        <translation>設定(&amp;S)</translation>
    </message>
    <message>
        <location filename="gui/MainWindow.cpp" line="218"/>
        <source>&amp;Tool Bar</source>
        <translation>ツールバー(&amp;T)</translation>
    </message>
    <message>
        <location filename="gui/MainWindow.cpp" line="549"/>
        <source>Confirmation</source>
        <translation>確認</translation>
    </message>
    <message>
        <location filename="gui/MainWindow.cpp" line="552"/>
        <source>Function(s) and/or data exist in the list.
Are you sure you want to quit?</source>
        <translation>関数やデータがリスト中にあります。
本当に終了しますか?</translation>
    </message>
    <message>
        <location filename="gui/MainWindow.cpp" line="553"/>
        <source>&amp;Cancel</source>
        <translation>キャンセル(&amp;C)</translation>
    </message>
    <message>
        <location filename="gui/MainWindow.cpp" line="153"/>
        <source>load &quot;&amp;lt;input-file&amp;gt;&quot;</source>
        <translation>load &quot;&amp;lt;入力ファイル&amp;gt;&quot;</translation>
    </message>
    <message>
        <location filename="gui/MainWindow.cpp" line="166"/>
        <source>save &apos;&amp;lt;filename&amp;gt;&apos;</source>
        <translation>save &apos;&amp;lt;ファイル名&amp;gt;&apos;</translation>
    </message>
    <message>
        <location filename="gui/MainWindow.cpp" line="227"/>
        <source>What&apos;s &amp;This?</source>
        <translation>これは何?(&amp;T)</translation>
    </message>
    <message>
        <location filename="gui/MainWindow.cpp" line="228"/>
        <source>Shift+F1</source>
        <translation>Shift+F1</translation>
    </message>
    <message>
        <location filename="gui/MainWindow.cpp" line="159"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="gui/MainWindow.cpp" line="172"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="gui/MainWindow.cpp" line="529"/>
        <source>: a GUI front-end to gnuplot&lt;br&gt;Copyright (C) 2007 Muneyuki Noguchi&lt;/p&gt;&lt;p&gt;This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.&lt;/p&gt;&lt;p&gt;This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.&lt;/p&gt;&lt;p&gt;You should have received a copy of the GNU General Public License along with this program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.&lt;/p&gt;</source>
        <translation>: gnuplot の GUI フロントエンド&lt;br&gt;Copyright (C) 2007 Muneyuki Noguchi&lt;/p&gt;&lt;p&gt;このプログラムはフリーソフトウェアです。あなたはこれを、フリーソフトウェア財団によって発行された GNU 一般公衆利用許諾契約書（バージョン2か、希望によってはそれ以降のバージョンのうちどれか）の定める条件の下で再頒布または改変することができます。&lt;/p&gt;&lt;p&gt;このプログラムは有用であることを願って頒布されますが、*全くの無保証* です。商業可能性の保証や特定の目的への適合性は、言外に示されたものも含め全く存在しません。詳しくはGNU 一般公衆利用許諾契約書をご覧ください。&lt;/p&gt;&lt;p&gt;あなたはこのプログラムと共に、GNU 一般公衆利用許諾契約書の複製物を一部受け取ったはずです。もし受け取っていなければ、フリーソフトウェア財団まで請求してください（宛先は the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA）。&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>Mapping</name>
    <message>
        <location filename="opt/Mapping.cpp" line="22"/>
        <source>cartesian</source>
        <translation>直交</translation>
    </message>
    <message>
        <location filename="opt/Mapping.cpp" line="23"/>
        <source>spherical</source>
        <translation>極</translation>
    </message>
    <message>
        <location filename="opt/Mapping.cpp" line="24"/>
        <source>cylindrical</source>
        <translation>円筒</translation>
    </message>
</context>
<context>
    <name>MappingOptionWidget</name>
    <message>
        <location filename="gui/opt/MappingOptionWidget.cpp" line="29"/>
        <source>Coordinate</source>
        <translation>座標</translation>
    </message>
</context>
<context>
    <name>OptionDialog</name>
    <message>
        <location filename="gui/OptionDialog.cpp" line="123"/>
        <source>&amp;Default</source>
        <translation>標準設定(&amp;D)</translation>
    </message>
    <message>
        <location filename="gui/OptionDialog.cpp" line="130"/>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <location filename="gui/OptionDialog.cpp" line="223"/>
        <source>&amp;Apply</source>
        <translation>適用(&amp;A)</translation>
    </message>
    <message>
        <location filename="gui/OptionDialog.cpp" line="223"/>
        <source>&amp;Cancel</source>
        <translation>キャンセル(&amp;C)</translation>
    </message>
    <message>
        <location filename="gui/OptionDialog.cpp" line="75"/>
        <source>Settings</source>
        <translation>設定</translation>
    </message>
    <message>
        <location filename="gui/OptionDialog.cpp" line="218"/>
        <source>Unsaved Changes</source>
        <translation>未保存の変更</translation>
    </message>
    <message>
        <location filename="gui/OptionDialog.cpp" line="222"/>
        <source>There are unsaved changes in this option.
Do you want to apply the changes before opening the new option?</source>
        <translation>このオプションには未保存の変更があります。
新しいオプションを開く前に変更を適用しますか?</translation>
    </message>
    <message>
        <location filename="gui/OptionDialog.cpp" line="223"/>
        <source>&amp;Discard</source>
        <translation>破棄(&amp;D)</translation>
    </message>
</context>
<context>
    <name>OutputOptionWidget</name>
    <message>
        <location filename="gui/opt/OutputOptionWidget.cpp" line="33"/>
        <source>Output</source>
        <translation>出力</translation>
    </message>
    <message>
        <location filename="gui/opt/OutputOptionWidget.cpp" line="45"/>
        <source>&amp;Specify</source>
        <translation>指定する(&amp;S)</translation>
    </message>
    <message>
        <location filename="gui/opt/OutputOptionWidget.cpp" line="56"/>
        <source>&amp;Open...</source>
        <translation>開く(&amp;O)...</translation>
    </message>
    <message>
        <location filename="gui/opt/OutputOptionWidget.cpp" line="102"/>
        <source>Set output</source>
        <translation>出力を設定</translation>
    </message>
</context>
<context>
    <name>ParametricOptionWidget</name>
    <message>
        <location filename="gui/opt/ParametricOptionWidget.cpp" line="28"/>
        <source>Parameter</source>
        <translation>媒介変数</translation>
    </message>
    <message>
        <location filename="gui/opt/ParametricOptionWidget.cpp" line="40"/>
        <source>Parametric Functions</source>
        <translation>媒介変数表示</translation>
    </message>
</context>
<context>
    <name>PlotModifierWidget</name>
    <message>
        <location filename="gui/plot/PlotModifierWidget.cpp" line="45"/>
        <source> Column:</source>
        <translation> 列:</translation>
    </message>
    <message>
        <location filename="gui/plot/PlotModifierWidget.cpp" line="56"/>
        <source>Specify a S&amp;tarting Index</source>
        <translation>開始インデックスを指定する(&amp;T)</translation>
    </message>
    <message>
        <location filename="gui/plot/PlotModifierWidget.cpp" line="65"/>
        <source>Specify a &amp;Ending Index</source>
        <translation>終了インデックスを指定する(&amp;E)</translation>
    </message>
    <message>
        <location filename="gui/plot/PlotModifierWidget.cpp" line="74"/>
        <source>Specify I&amp;ncrement of Index</source>
        <translation>インデックスの増分を指定する(&amp;N)</translation>
    </message>
    <message>
        <location filename="gui/plot/PlotModifierWidget.cpp" line="83"/>
        <source>Specify Point Increment</source>
        <translation>点の増分を指定する</translation>
    </message>
    <message>
        <location filename="gui/plot/PlotModifierWidget.cpp" line="90"/>
        <source>Specify Line Increment</source>
        <translation>線の増分を指定する</translation>
    </message>
    <message>
        <location filename="gui/plot/PlotModifierWidget.cpp" line="97"/>
        <source>Specify a Start Point</source>
        <translation>開始点を指定する</translation>
    </message>
    <message>
        <location filename="gui/plot/PlotModifierWidget.cpp" line="104"/>
        <source>Specify a Start Line</source>
        <translation>開始線を指定する</translation>
    </message>
    <message>
        <location filename="gui/plot/PlotModifierWidget.cpp" line="111"/>
        <source>Specify a End Point</source>
        <translation>終了点を指定する</translation>
    </message>
    <message>
        <location filename="gui/plot/PlotModifierWidget.cpp" line="118"/>
        <source>Specify a End Line</source>
        <translation>終了線を指定する</translation>
    </message>
    <message>
        <location filename="gui/plot/PlotModifierWidget.cpp" line="125"/>
        <source>Specify</source>
        <translation>指定する</translation>
    </message>
    <message>
        <location filename="gui/plot/PlotModifierWidget.cpp" line="206"/>
        <source>Co&amp;lumns</source>
        <translation>列(&amp;L)</translation>
    </message>
    <message>
        <location filename="gui/plot/PlotModifierWidget.cpp" line="33"/>
        <source>Data File</source>
        <translation>データファイル</translation>
    </message>
    <message>
        <location filename="gui/plot/PlotModifierWidget.cpp" line="205"/>
        <source>&amp;Sampling</source>
        <translation>サンプリング(&amp;S)</translation>
    </message>
    <message>
        <location filename="gui/plot/PlotModifierWidget.cpp" line="204"/>
        <source>&amp;Indexes</source>
        <translation>インデックス(&amp;I)</translation>
    </message>
    <message>
        <location filename="gui/plot/PlotModifierWidget.cpp" line="207"/>
        <source>S&amp;moothing</source>
        <translation>平滑化(&amp;M)</translation>
    </message>
    <message>
        <location filename="gui/plot/PlotModifierWidget.cpp" line="52"/>
        <source>Fo&amp;rmat:</source>
        <translation>フォーマット(&amp;R):</translation>
    </message>
    <message>
        <location filename="gui/plot/PlotModifierWidget.cpp" line="37"/>
        <source>plot {index &amp;lt;index list&amp;gt;}&lt;br&gt;{every &amp;lt;every list&amp;gt;}&lt;br&gt;{using &amp;lt;using list&amp;gt;}&lt;br&gt;{smooth &amp;lt;option&amp;gt;}</source>
        <translation>plot {index &amp;lt;index リスト&amp;gt;}&lt;br&gt;{every &amp;lt;every リスト&amp;gt;}&lt;br&gt;{using &amp;lt;using リスト&amp;gt;}&lt;br&gt;{smooth &amp;lt;オプション&amp;gt;}</translation>
    </message>
    <message>
        <location filename="gui/plot/PlotModifierWidget.cpp" line="150"/>
        <source>plot {index &amp;lt;index list&amp;gt;}</source>
        <translation>plot {index &amp;lt;index リスト&amp;gt;}</translation>
    </message>
    <message>
        <location filename="gui/plot/PlotModifierWidget.cpp" line="172"/>
        <source>plot {every &amp;lt;every list&amp;gt;}</source>
        <translation>plot {every &amp;lt;every リスト&amp;gt;}</translation>
    </message>
    <message>
        <location filename="gui/plot/PlotModifierWidget.cpp" line="188"/>
        <source>plot {using &amp;lt;using list&amp;gt;}</source>
        <translation>plot {using &amp;lt;using リスト&amp;gt;}</translation>
    </message>
    <message>
        <location filename="gui/plot/PlotModifierWidget.cpp" line="200"/>
        <source>plot {smooth &amp;lt;option&amp;gt;}</source>
        <translation>plot {smooth &amp;lt;オプション&amp;gt;}</translation>
    </message>
</context>
<context>
    <name>PlotOptionDialog</name>
    <message>
        <location filename="gui/PlotOptionDialog.cpp" line="83"/>
        <source>&amp;Apply</source>
        <translation>適用(&amp;A)</translation>
    </message>
    <message>
        <location filename="gui/PlotOptionDialog.cpp" line="87"/>
        <source>&amp;Cancel</source>
        <translation>キャンセル(&amp;C)</translation>
    </message>
    <message>
        <location filename="gui/PlotOptionDialog.cpp" line="77"/>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <location filename="gui/PlotOptionDialog.cpp" line="113"/>
        <source>Options of %1 %2</source>
        <translation>%1 %2 のオプション</translation>
    </message>
    <message>
        <location filename="gui/PlotOptionDialog.cpp" line="113"/>
        <source>Function</source>
        <translation>関数</translation>
    </message>
    <message>
        <location filename="gui/PlotOptionDialog.cpp" line="113"/>
        <source>Data File</source>
        <translation>データファイル</translation>
    </message>
    <message>
        <location filename="gui/PlotOptionDialog.cpp" line="65"/>
        <source>&amp;2D Plot Test</source>
        <translation>&amp;2D プロットテスト</translation>
    </message>
    <message>
        <location filename="gui/PlotOptionDialog.cpp" line="73"/>
        <source>&amp;3D Plot Test</source>
        <translation>&amp;3D プロットテスト</translation>
    </message>
</context>
<context>
    <name>PlotOthersWidget</name>
    <message>
        <location filename="gui/plot/PlotOthersWidget.cpp" line="30"/>
        <source>Others</source>
        <translation>その他</translation>
    </message>
    <message>
        <location filename="gui/plot/PlotOthersWidget.cpp" line="41"/>
        <source>A&amp;xes</source>
        <translation>軸(&amp;X)</translation>
    </message>
    <message>
        <location filename="gui/plot/PlotOthersWidget.cpp" line="42"/>
        <source>plot {axes &amp;lt;axes&amp;gt;}</source>
        <translation>plot {axes &amp;lt;軸&amp;gt;}</translation>
    </message>
</context>
<context>
    <name>PlotStyleWidget</name>
    <message>
        <location filename="gui/plot/PlotStyleWidget.cpp" line="35"/>
        <source>Specify</source>
        <translation>指定する</translation>
    </message>
    <message>
        <location filename="gui/plot/PlotStyleWidget.cpp" line="31"/>
        <source>Style</source>
        <translation>スタイル</translation>
    </message>
    <message>
        <location filename="gui/plot/PlotStyleWidget.cpp" line="45"/>
        <source>Specify a Line Type</source>
        <translation>線の種類を指定する</translation>
    </message>
    <message>
        <location filename="gui/plot/PlotStyleWidget.cpp" line="52"/>
        <source>Specify Line Width</source>
        <translation>線の幅を指定する</translation>
    </message>
    <message>
        <location filename="gui/plot/PlotStyleWidget.cpp" line="59"/>
        <source>Specify a Point Type</source>
        <translation>点の種類を指定する</translation>
    </message>
    <message>
        <location filename="gui/plot/PlotStyleWidget.cpp" line="66"/>
        <source>Specify Point Size</source>
        <translation>点のサイズを指定する</translation>
    </message>
    <message>
        <location filename="gui/plot/PlotStyleWidget.cpp" line="32"/>
        <source>plot {with &amp;lt;style&amp;gt;}</source>
        <translation>plot {with &amp;lt;スタイル&amp;gt;}</translation>
    </message>
</context>
<context>
    <name>PlotTitleWidget</name>
    <message>
        <location filename="gui/plot/PlotTitleWidget.cpp" line="33"/>
        <source>&amp;Default</source>
        <translation>標準設定(&amp;D)</translation>
    </message>
    <message>
        <location filename="gui/plot/PlotTitleWidget.cpp" line="37"/>
        <source>&amp;No Title</source>
        <translation>タイトルなし(&amp;N)</translation>
    </message>
    <message>
        <location filename="gui/plot/PlotTitleWidget.cpp" line="40"/>
        <source>C&amp;ustom Title</source>
        <translation>カスタムタイトル(&amp;U)</translation>
    </message>
    <message>
        <location filename="gui/plot/PlotTitleWidget.cpp" line="29"/>
        <source>Title</source>
        <translation>タイトル</translation>
    </message>
    <message>
        <location filename="gui/plot/PlotTitleWidget.cpp" line="30"/>
        <source>plot {&amp;lt;title-spec&amp;gt;}</source>
        <translation>plot {&amp;lt;タイトル指定&amp;gt;}</translation>
    </message>
</context>
<context>
    <name>Process</name>
    <message>
        <location filename="gui/Process.cpp" line="73"/>
        <source>Open gnuplot</source>
        <translation>gnuplot を開く</translation>
    </message>
    <message>
        <location filename="gui/Process.cpp" line="34"/>
        <source>Gnuplot could not be started</source>
        <translation>Gnuplot を起動できませんでした</translation>
    </message>
</context>
<context>
    <name>RawCommandDialog</name>
    <message>
        <location filename="gui/RawCommandDialog.cpp" line="48"/>
        <source>Raw Commands</source>
        <translation>生のコマンド</translation>
    </message>
    <message>
        <location filename="gui/RawCommandDialog.cpp" line="55"/>
        <source>&amp;Execute</source>
        <translation>実行(&amp;E)</translation>
    </message>
    <message>
        <location filename="gui/RawCommandDialog.cpp" line="63"/>
        <source>&amp;Close</source>
        <translation>閉じる(&amp;C)</translation>
    </message>
</context>
<context>
    <name>SamplesOptionWidget</name>
    <message>
        <location filename="gui/opt/SamplesOptionWidget.cpp" line="29"/>
        <source>Sampling</source>
        <translation>サンプリング</translation>
    </message>
    <message>
        <location filename="gui/opt/SamplesOptionWidget.cpp" line="55"/>
        <source>Samples</source>
        <translation>サンプル</translation>
    </message>
</context>
<context>
    <name>SizeOptionWidget</name>
    <message>
        <location filename="gui/opt/SizeOptionWidget.cpp" line="30"/>
        <source>Size</source>
        <translation>サイズ</translation>
    </message>
    <message>
        <location filename="gui/opt/SizeOptionWidget.cpp" line="42"/>
        <source>&amp;Specify Ratio</source>
        <translation>比率を指定する(&amp;S)</translation>
    </message>
    <message>
        <location filename="gui/opt/SizeOptionWidget.cpp" line="58"/>
        <source>&amp;Horizontal Size:</source>
        <translation>水平サイズ(&amp;H):</translation>
    </message>
    <message>
        <location filename="gui/opt/SizeOptionWidget.cpp" line="66"/>
        <source>&amp;Vertical Size:</source>
        <translation>垂直サイズ(&amp;V):</translation>
    </message>
</context>
<context>
    <name>TerminalLatexEmtex</name>
    <message>
        <location filename="opt/terminal/TerminalLatexEmtex.cpp" line="23"/>
        <source>default</source>
        <translation>標準設定</translation>
    </message>
</context>
<context>
    <name>TerminalLatexEmtexOptionWidget</name>
    <message>
        <location filename="gui/opt/terminal/TerminalLatexEmtexOptionWidget.cpp" line="49"/>
        <source>&amp;Font:</source>
        <translation>フォント(&amp;F):</translation>
    </message>
    <message>
        <location filename="gui/opt/terminal/TerminalLatexEmtexOptionWidget.cpp" line="57"/>
        <source>&amp;Size:</source>
        <translation>サイズ(&amp;S):</translation>
    </message>
</context>
<context>
    <name>TerminalOptionWidget</name>
    <message>
        <location filename="gui/opt/TerminalOptionWidget.cpp" line="57"/>
        <source>Terminal</source>
        <translation>端末</translation>
    </message>
    <message>
        <location filename="gui/opt/TerminalOptionWidget.cpp" line="91"/>
        <source>&amp;Initialize Terminal Options</source>
        <translation>端末のオプションを初期化(&amp;I)</translation>
    </message>
    <message>
        <location filename="gui/opt/TerminalOptionWidget.cpp" line="78"/>
        <source>&amp;Terminal Type:</source>
        <translation>端末の種類(&amp;T):</translation>
    </message>
</context>
<context>
    <name>TerminalPbm</name>
    <message>
        <location filename="opt/terminal/TerminalPbm.cpp" line="22"/>
        <source>small</source>
        <translation>小</translation>
    </message>
    <message>
        <location filename="opt/terminal/TerminalPbm.cpp" line="23"/>
        <source>medium</source>
        <translation>中</translation>
    </message>
    <message>
        <location filename="opt/terminal/TerminalPbm.cpp" line="24"/>
        <source>large</source>
        <translation>大</translation>
    </message>
    <message>
        <location filename="opt/terminal/TerminalPbm.cpp" line="29"/>
        <source>monochrome</source>
        <translation>モノクロ</translation>
    </message>
    <message>
        <location filename="opt/terminal/TerminalPbm.cpp" line="30"/>
        <source>gray</source>
        <translation>グレー</translation>
    </message>
    <message>
        <location filename="opt/terminal/TerminalPbm.cpp" line="31"/>
        <source>color</source>
        <translation>カラー</translation>
    </message>
</context>
<context>
    <name>TerminalPbmOptionWidget</name>
    <message>
        <location filename="gui/opt/terminal/TerminalPbmOptionWidget.cpp" line="48"/>
        <source>&amp;Font Size:</source>
        <translation>フォントのサイズ(&amp;F):</translation>
    </message>
    <message>
        <location filename="gui/opt/terminal/TerminalPbmOptionWidget.cpp" line="60"/>
        <source>Co&amp;lormode:</source>
        <translation>色モード(&amp;L):</translation>
    </message>
</context>
<context>
    <name>TerminalPostScript</name>
    <message>
        <location filename="opt/terminal/TerminalPostScript.cpp" line="22"/>
        <source>landscape</source>
        <translation>横方向</translation>
    </message>
    <message>
        <location filename="opt/terminal/TerminalPostScript.cpp" line="23"/>
        <source>portrait</source>
        <translation>縦方向</translation>
    </message>
    <message>
        <location filename="opt/terminal/TerminalPostScript.cpp" line="29"/>
        <source>color</source>
        <translation>カラー</translation>
    </message>
    <message>
        <location filename="opt/terminal/TerminalPostScript.cpp" line="30"/>
        <source>monochrome</source>
        <translation>モノクロ</translation>
    </message>
    <message>
        <location filename="opt/terminal/TerminalPostScript.cpp" line="35"/>
        <source>solid</source>
        <translation>実線</translation>
    </message>
    <message>
        <location filename="opt/terminal/TerminalPostScript.cpp" line="36"/>
        <source>dashed</source>
        <translation>破線</translation>
    </message>
</context>
<context>
    <name>TerminalPostScriptOptionWidget</name>
    <message>
        <location filename="gui/opt/terminal/TerminalPostScriptOptionWidget.cpp" line="51"/>
        <source>&amp;Mode:</source>
        <translation>モード(&amp;M):</translation>
    </message>
    <message>
        <location filename="gui/opt/terminal/TerminalPostScriptOptionWidget.cpp" line="63"/>
        <source>Co&amp;lor:</source>
        <translation>色(&amp;L):</translation>
    </message>
    <message>
        <location filename="gui/opt/terminal/TerminalPostScriptOptionWidget.cpp" line="75"/>
        <source>Da&amp;shed:</source>
        <translation>破線(&amp;S):</translation>
    </message>
    <message>
        <location filename="gui/opt/terminal/TerminalPostScriptOptionWidget.cpp" line="83"/>
        <source>&amp;Font Name:</source>
        <translation>フォントの名前(&amp;F):</translation>
    </message>
    <message>
        <location filename="gui/opt/terminal/TerminalPostScriptOptionWidget.cpp" line="91"/>
        <source>Fo&amp;nt Size:</source>
        <translation>フォントのサイズ(&amp;N):</translation>
    </message>
    <message>
        <location filename="gui/opt/terminal/TerminalPostScriptOptionWidget.cpp" line="95"/>
        <source>&amp;Enhanced</source>
        <translation>強化(&amp;E)</translation>
    </message>
</context>
<context>
    <name>TitleOptionWidget</name>
    <message>
        <location filename="gui/opt/TitleOptionWidget.cpp" line="30"/>
        <source>Title</source>
        <translation>タイトル</translation>
    </message>
    <message>
        <location filename="gui/opt/TitleOptionWidget.cpp" line="46"/>
        <source>T&amp;ext:</source>
        <translation>テキスト(&amp;E):</translation>
    </message>
    <message>
        <location filename="gui/opt/TitleOptionWidget.cpp" line="55"/>
        <source>&amp;X Offset:</source>
        <translation>&amp;X オフセット:</translation>
    </message>
    <message>
        <location filename="gui/opt/TitleOptionWidget.cpp" line="64"/>
        <source>&amp;Y Offset:</source>
        <translation>&amp;Y オフセット:</translation>
    </message>
    <message>
        <location filename="gui/opt/TitleOptionWidget.cpp" line="72"/>
        <source>&amp;Font Name:</source>
        <translation>フォントの名前(&amp;F):</translation>
    </message>
</context>
<context>
    <name>ViewOptionWidget</name>
    <message>
        <location filename="gui/opt/ViewOptionWidget.cpp" line="30"/>
        <source>View</source>
        <translation>視点</translation>
    </message>
    <message>
        <location filename="gui/opt/ViewOptionWidget.cpp" line="42"/>
        <source>&amp;Map</source>
        <translation>地図(&amp;M)</translation>
    </message>
    <message>
        <location filename="gui/opt/ViewOptionWidget.cpp" line="54"/>
        <source>&amp;X Axis</source>
        <translation>&amp;X 軸</translation>
    </message>
    <message>
        <location filename="gui/opt/ViewOptionWidget.cpp" line="67"/>
        <source>&amp;Z Axis</source>
        <translation>&amp;Z 軸</translation>
    </message>
    <message>
        <location filename="gui/opt/ViewOptionWidget.cpp" line="79"/>
        <source>&amp;Scale</source>
        <translation>縮尺(&amp;S)</translation>
    </message>
    <message>
        <location filename="gui/opt/ViewOptionWidget.cpp" line="91"/>
        <source>Sca&amp;le of Z Axis</source>
        <translation>Z 軸の縮尺(&amp;L)</translation>
    </message>
</context>
</TS>
